import { login } from '../api/User'
import { singleton } from '../decorator/singleton.decorator'
import { getToken, removeToken, setToken } from '../utils/cookies'

const EIP721_DOMAIN_DATA = [
  { name: 'name', type: 'string' },
  { name: 'version', type: 'string' },
]

@singleton
class UserModuleClass {
  public token: string = getToken()
  public accountId: string = ''
  public chainId: number = 0
  public walletConnected: boolean = false
  public step: number = 0
  public nonce = ''

  get encodeToken() {
    return encodeURIComponent(this.token)
  }

  public updateAccount(val: string) {
    this.accountId = val
  }

  public updateChainID(val: number) {
    this.chainId = val
  }
  public updateWalletStatus(val: boolean) {
    this.walletConnected = val
  }

  public updateStep(val: number) {
    this.step = val
  }

  public updateNonce(val: string) {
    this.nonce = val
  }

  public async Login({
    bcInstance,
    account,
    chainId,
    nonce,
  }: {
    bcInstance: any
    account: string
    chainId: string | number
    nonce: string
  }) {
    nonce += ''
    const tips = 'This signature is only used for verify your account'
    const signMsg = {
      tips,
      nonce,
    }

    const signObj = {
      types: {
        EIP712Domain: EIP721_DOMAIN_DATA,
        set: [
          { name: 'tips', type: 'string' },
          { name: 'nonce', type: 'string' },
        ],
      },
      primaryType: 'set',
      domain: {
        name: 'Auth',
        version: '1',
      },
      message: signMsg,
    }
    const signature = await bcInstance.signData(signObj, account)
    const authData = {
      account,
      nonce,
      signature,
      tips,
      net_id: chainId,
    }
    console.log('login data: ', authData)
    const res: any = await login(authData)
    if (!res.errcode && res.token) {
      setToken(res.token)
      this.token = res.token
    }
  }

  public LogOut() {
    if (this.token === '') {
      return
    }
    // await logout()
    removeToken()
    this.token = ''
  }
}

export const UserModule = new UserModuleClass()
