import axios from 'axios'
import { UserModule } from '../module/UserModule'
import { EventBus, SHOW_ERR_MSG } from './event-bus'

const service = axios.create({
  baseURL: 'https://market.cebg.games',
  timeout: 5000,
})

// Request interceptors
service.interceptors.request.use(
  (config) => {
    // Add X-Access-Token header to every request, you can add other custom headers here
    if (UserModule.token) {
      if (config.url) {
        if (config.url.indexOf('?') > 0) {
          config.url += `&token=${UserModule.encodeToken}`
        } else {
          config.url += `?token=${UserModule.encodeToken}`
        }
        if (config.url.indexOf('account=') < 0 && UserModule.accountId) {
          config.url += `&account=${UserModule.accountId}`
        }
        if (config.url.indexOf('net_id=') < 0 && UserModule.chainId) {
          config.url += `&net_id=${UserModule.chainId}`
        }
      }
    }
    config.headers['Content-Type'] = 'application/json'
    return config
  },
  (error) => {
    Promise.reject(error)
  },
)

// Response interceptors
service.interceptors.response.use(
  (response) => {
    // Some example codes here:
    // code == 0: success
    // code == 10: username or password is incorrect
    // You can change this part for your own usage.
    const res = response.data
    if (res.errcode) {
      // Message({
      //   message: res.errmsg || 'Error',
      //   type: 'error',
      //   duration: 5 * 1000
      // })
      return Promise.reject(new Error(res.errmsg || 'Error'))
    } else {
      return response.data
    }
  },
  (error) => {
    EventBus.$emit(SHOW_ERR_MSG, error.message)
    return Promise.reject(error)
  },
)

export default service
